// MassBuilderSaveTool
// Copyright (C) 2021 Guillaume Jacquemin
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <https://www.gnu.org/licenses/>.

#include "../BinaryReader.h"
#include "../BinaryWriter.h"

#include "GuidPropertySerialiser.h"

auto GuidPropertySerialiser::deserialiseProperty(const std::string& name, const std::string& type, UnsignedLong value_length,
                                                 BinaryReader& reader, PropertySerialiser& serialiser) -> UnrealPropertyBase::ptr
{
    auto prop = Containers::pointer<GuidStructProperty>();

    if(!reader.readStaticArray(prop->guid)) {
        Utility::Error{} << "Couldn't read guid in" << __func__;
        return nullptr;
    }

    return prop;
}

auto GuidPropertySerialiser::serialiseProperty(UnrealPropertyBase::ptr& prop, UnsignedLong& bytes_written,
                                               BinaryWriter& writer, PropertySerialiser& serialiser) -> bool
{
    auto guid_prop = dynamic_cast<GuidStructProperty*>(prop.get());

    if(!guid_prop) {
        return false;
    }

    bytes_written += writer.writeDataToArray<char>({guid_prop->guid.data(), guid_prop->guid.size()});

    return true;
}
